@@ -1,6 +1,6 @@
 /*
- * Copyright (C) 2006, Mr Jamie McCracken (jamiemcc@gnome.org)
- * Copyright (C) 2008, Nokia (urho.konttori@nokia.com)
+ * Copyright (C) 2006, Jamie McCracken <jamiemcc@gnome.org>
+ * Copyright (C) 2008, Nokia <ivan.frade@nokia.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,7 +25,7 @@
 
 #include <libtracker-common/tracker-ontologies.h>
 
-#include <libtracker-db/tracker-db-interface.h>
+#include "tracker-db-interface.h"
 
 G_BEGIN_DECLS
 
@@ -50,6 +50,9 @@ typedef void (*TrackerStatementCallback) (const gchar *graph,
                                           GPtrArray   *rdf_types,
                                           gpointer     user_data);
 typedef void (*TrackerCommitCallback)    (gpointer     user_data);
+typedef void (*TrackerBusyCallback)      (const gchar *status,
+                                          gdouble      progress,
+                                          gpointer     user_data);
 
 GQuark   tracker_data_error_quark                   (void);
 
@@ -80,6 +83,7 @@ void     tracker_data_insert_statement_with_string  (const gchar               *
 void     tracker_data_begin_db_transaction          (void);
 void     tracker_data_begin_db_transaction_for_replay (time_t                   time);
 void     tracker_data_commit_db_transaction         (void);
+void     tracker_data_notify_db_transaction         (void);
 void     tracker_data_begin_transaction             (GError                   **error);
 void     tracker_data_commit_transaction            (GError                   **error);
 void     tracker_data_rollback_transaction          (void);
@@ -93,17 +97,32 @@ void     tracker_data_update_buffer_might_flush     (GError                   **
 
 void     tracker_data_sync                          (void);
 void     tracker_data_replay_journal                (GHashTable                *classes,
-                                                     GHashTable                *properties);
+                                                     GHashTable                *properties,
+                                                     GHashTable                *id_uri_map,
+                                                     TrackerBusyCallback        busy_callback,
+                                                     gpointer                   busy_user_data,
+                                                     const gchar               *busy_status);
 
 /* Calling back */
-void     tracker_data_add_insert_statement_callback   (TrackerStatementCallback   callback,
-                                                       gpointer                   user_data);
-void     tracker_data_add_delete_statement_callback   (TrackerStatementCallback   callback,
-                                                       gpointer                   user_data);
-void     tracker_data_add_commit_statement_callback   (TrackerCommitCallback      callback,
-                                                       gpointer                   user_data);
-void     tracker_data_add_rollback_statement_callback (TrackerCommitCallback      callback,
-                                                       gpointer                   user_data);
+void     tracker_data_add_insert_statement_callback      (TrackerStatementCallback   callback,
+                                                          gpointer                   user_data);
+void     tracker_data_add_delete_statement_callback      (TrackerStatementCallback   callback,
+                                                          gpointer                   user_data);
+void     tracker_data_add_commit_statement_callback      (TrackerCommitCallback      callback,
+                                                          gpointer                   user_data);
+void     tracker_data_add_rollback_statement_callback    (TrackerCommitCallback      callback,
+                                                          gpointer                   user_data);
+void     tracker_data_remove_insert_statement_callback   (TrackerStatementCallback   callback,
+                                                          gpointer                   user_data);
+void     tracker_data_remove_delete_statement_callback   (TrackerStatementCallback   callback,
+                                                          gpointer                   user_data);
+void     tracker_data_remove_commit_statement_callback   (TrackerCommitCallback      callback,
+                                                          gpointer                   user_data);
+void     tracker_data_remove_rollback_statement_callback (TrackerCommitCallback      callback,
+                                                          gpointer                   user_data);
+
+void     tracker_data_update_shutdown                 (void);
+#define  tracker_data_update_init                     tracker_data_update_shutdown
 
 G_END_DECLS
 
